
История изменений
=================

0.6 (2012-03-20)
================
* longtitude везде переименованы в longitude;
* фильтр ``static_map_url`` и тег ``yandex_map`` теперь поддерживают
  Point из GeoDjango (можно их применять к PointField с уже заполненными
  координатами);
* тесты запускаются через tox;
* в yandex_maps.api большие функции разбиты на более маленькие, чтоб их можно
  было использовать отдельно.

0.5.1 (2010-08-29)
==================

django-yandex-maps переименован в yandex-maps
